package com.yun.mshu;

import android.content.Context;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;

import com.meishu.sdk.core.ad.recycler.RecyclerAdMediaListener;
import com.meishu.sdk.core.utils.MsAdPatternType;
import com.meishu.sdk.core.utils.MsInteractionType;
import com.meishu.sdk.platform.custom.recycler.MsCustomRecyclerAdapter;
import com.meishu.sdk.platform.custom.recycler.MsCustomRecyclerFeedAd;
import com.open.ad.polyunion.bean.CAdInfo;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.NativeAdsResponse;

import java.util.List;

/**
 * @author zw
 * @date :2025/2/8 14:59
 * @projectName
 * @description:
 */
public class CustomFeedAd extends MsCustomRecyclerFeedAd {

    private MsCustomRecyclerAdapter adWrapper;
    private NativeAdsResponse response;

    public CustomFeedAd(MsCustomRecyclerAdapter adWrapper, NativeAdsResponse response) {
        super(adWrapper);
        this.adWrapper = adWrapper;
        this.response = response;
    }


    @Override
    public int getAdPatternType() {
        int imageMode = response.getSelfRenderAdMediaType();
        int adPatternType = MsAdPatternType.LARGE_IMAGE;
        switch (imageMode) {
            case NativeAdsResponse.NATIVE_AD_MEDIA_TYPE_VIDEO:
                adPatternType = MsAdPatternType.VIDEO;
                break;
            default:
                    adPatternType = MsAdPatternType.IMAGE;
                    break;
        }
        return adPatternType;
    }

    @Override
    public int getInteractionType() {
        int interactionType = MsInteractionType.NORMAL;
        switch (response.getInteractionType()){
            case AdConfig.NATIVE_INTERACTION_TYPE_DOWNLOAD:
                interactionType = MsInteractionType.DOWNLOAD_APP;
                break;
            default:
                interactionType = MsInteractionType.NORMAL;
                break;
        }
        return interactionType;
    }



    @Override
    protected void bindAdToView(Context context, ViewGroup container, List<View> clickableViews) {
        //创意点击views是指，点击对应的views会执行广告的目的，比如下载app、跳转目标网页等
        //clickableViews，在视频类广告中，点击clickableViews会跳转到视频页面
        //viewGroup参数必须为container的根view，否则穿山甲无法加载广告
        response.setNativeActionListener(new NativeAdsResponse.NativeActionListener() {
            @Override
            public void onAdClick() {
                adWrapper.onFeedAdClicked(CustomFeedAd.this);
            }

            @Override
            public void onAdShow(CAdInfo cAdInfo) {
                adWrapper.onFeedAdExposure(CustomFeedAd.this);
            }

            @Override
            public void onError(String s) {

            }

            @Override
            public void onAdClose(String s) {
                Log.e("CLOOOUD_POLY", "onAdClose: " );
            }

            @Override
            public void onExpressRenderFail(String s) {
            }

            @Override
            public void onExpressRenderSuccess(View view, float v, float v1) {

            }

            @Override
            public void onExpressRenderTimeout() {

            }

            @Override
            public void onDislikeDialogShow() {

            }

            @Override
            public void onDownloadConfirmDialogDismissed() {

            }
        });
        try {
            // 注册原生信息流广告可点击区域视图，建议为客户端单个原生广告位所有区域，在广告展现时调用
            response.registerNativeClickableView(
                    (ViewGroup) container,
                    context,
                    (ViewGroup) container,
                    null);
        } catch (Throwable e) {
            e.printStackTrace();
        }

    }

    @Override
    public void bindMediaView(ViewGroup mediaView, RecyclerAdMediaListener nativeRecyclerAdMediaListener) {

        mediaView.removeAllViews();
        mediaView.addView(response.getVideoView(mediaView.getContext()));
    }

    @Override
    public String getTitle() {
        return response.getTitle();
    }

    @Override
    public String getContent() {
        return response.getDesc();
    }

    @Override
    public String getActionText() {
        return null;
    }

    @Override
    public String getIconUrl() {
        return response.getLogoUrl();
    }

    @Override
    public String getIconTitle() {
        return null;
    }

    @Override
    public String getFromLogo() {
        return null;
    }

    @Override
    public String getFrom() {
        return null;
    }

    @Override
    public String getFromId() {
        return null;
    }

    @Override
    public String getAppName() {
        return null;
    }

    @Override
    public String getPackageName() {
        return null;
    }

    @Override
    public String getDesc() {
        return null;
    }

    @Override
    public String[] getImgUrls() {
        //穿山甲逻辑：大图、一图、三图，图片都在ImageList中
        String imgUrls[] = null;
        List<String> images = response.getImageUrls();
        if (images != null) {
            imgUrls = new String[images.size()];
            int i = 0;
            for (String image : images) {
                imgUrls[i++] = image;
            }
        }
        return imgUrls;
    }

    @Override
    public String getVideoUrl() {
        return null;
    }

    @Override
    public long getDuration() {
        return 0;
    }

    @Override
    public int getWidth() {
        return 0;
    }

    @Override
    public int getHeight() {
        return 0;
    }

    @Override
    public void startVideo() {

    }

    @Override
    public void stopVideo() {

    }

    @Override
    public void pauseVideo() {

    }

    @Override
    public void resumeVideo() {

    }

    @Override
    public void replay() {

    }

    @Override
    public void mute() {

    }

    @Override
    public void unmute() {

    }

    @Override
    public void destroy() {
        if (response!=null){
            response.onDestroy();
            response=null;
        }
    }

    @Override
    public boolean isNativeExpress() {
        return false;
    }
}