package com.yun.mshu;

import android.app.Application;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.View;

import com.meishu.sdk.core.ad.AdSlot;
import com.meishu.sdk.core.ad.recycler.RecyclerAdData;
import com.meishu.sdk.core.ad.recycler.RecyclerMixAdLoader;
import com.meishu.sdk.core.ad.reward.RewardVideoLoader;
import com.meishu.sdk.core.domain.SdkAdInfo;
import com.meishu.sdk.core.utils.MsAdPatternType;
import com.meishu.sdk.platform.custom.recycler.MsCustomRecyclerAdapter;
import com.open.ad.cloooud.api.listener.COaidProvider;
import com.open.ad.polyunion.bean.CAdInfo;
import com.open.ad.polyunion.listener.NativeAdsListener;
import com.open.ad.polyunion.newedition.contract.DeniedUpDeviceInfo;
import com.open.ad.polyunion.newedition.contract.InitSDKListener;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.AdRequestConfig;
import com.open.ad.polyunion.view.AdView;
import com.open.ad.polyunion.view.InitSDKConfig;
import com.open.ad.polyunion.view.NativeAd;
import com.open.ad.polyunion.view.NativeAdsResponse;

import java.util.ArrayList;
import java.util.List;

/**
 * @author zw
 * @date :2025/2/8 15:00
 * @projectName
 * @description:
 */
public class CustomRecyclerAdLoader extends MsCustomRecyclerAdapter {


    public CustomRecyclerAdLoader(RecyclerMixAdLoader adLoader, SdkAdInfo sdkAdInfo) {
        super(adLoader, sdkAdInfo);
     }

    @Override
    public void loadCustomAd(String app_id, String s1, String pid, String s3) {
        try {
            //聚合SDK初始化
            InitSDKConfig initSDKConfig  = new InitSDKConfig.Builder()
                    .AppId(app_id)
//                    .setChannel("demo")//渠道
                    // 竖屏 - AdConfig.REWARD_VIDEO_SCREEN_VERTICAL
                    // 横屏 - AdConfig.REWARD_VIDEO_SCREEN_x`HORIZONTAL
                    .RewardVideoScreenDirection(AdConfig.REWARD_VIDEO_SCREEN_VERTICAL) // 设置激励视频播放页面的横竖屏
                    .debug(true)////上线需要设置false
                    .setDeniedUpDeviceInfo(new DeniedUpDeviceInfo() {
                    })
                    .setOaidProvider(new COaidProvider() {
                        @Override
                        public String getOaid() {
                            return "";
                        }
                    }) //传入 OAID 获取器，建议集成 OAID SDK的应用设置
                    .build();
            AdView.initSDK((Application) context.getApplicationContext(), initSDKConfig, new InitSDKListener() {
                @Override
                public void initializeSucceed() {
                    startLoadAd(pid);
                }

                @Override
                public void initializeFail() {
                    CustomRecyclerAdLoader.this.onError(10000,"初始化失败");
                    //初始化失败

                }
            });
        } catch (Throwable e) {
            CustomRecyclerAdLoader.this.onError(2000,e.getMessage());
        }
    }

    private void startLoadAd(String pid) {
        int fetchAdCount = getAdLoader().getFetchCount() <= 0 ? 1 : getAdLoader().getFetchCount();

        int adContentWidth = 1080;
        int adContentHeight = 1920;

        DisplayMetrics dm = context.getApplicationContext().getResources().getDisplayMetrics();
        float expressViewWidth;
        float expressViewHeight;

        if (getAdLoader().getAccept_ad_width() !=null &&0 < getAdLoader().getAccept_ad_width()){
            expressViewWidth  = getAdLoader().getAccept_ad_width()/ dm.density;
        } else {
            expressViewWidth = dm.widthPixels / dm.density;
        }

        if (getAdLoader().getAccept_ad_height()!=null && 0 < getAdLoader().getAccept_ad_height()){
            expressViewHeight = getAdLoader().getAccept_ad_height()/ dm.density;
        } else {
            expressViewHeight = 0; // 高设为 0，可以自适应
        }
        AdRequestConfig requestConfig = new AdRequestConfig.Builder()
                .AdType(AdConfig.AD_TYPE_INTERSTITIAL)
                .slotId(pid) //广告场景id
                .isVideoVoiceOn(false)//视频播放是否有声音
                .requestCount(1) //信息流广告请求条数
                .widthDp((int) expressViewWidth) //请求图片宽度dp值
                .heightDp(0) //请求图片高度dp值
                /**
                 * 设置视频自动播放场景：
                 * ALWAYS - 所有网络环境均自动播放
                 * WIFI - WIFI网络环境自动播放
                 * NEVER - 所有网络环境均不会自动播放
                 */
                .videoAutoPlayPolicy(AdRequestConfig.VideoAutoPlayPolicy.ALWAYS) //                .addSougouAdTemplate(AdTemplate.BIG_IMG_TPL_ID)
                //                .addSougouAdTemplate(AdTemplate.DOWNLOAD_BIG_TPL_ID)
                .showDownloadConfirmDialog(true)
                .build();

        NativeAd nativeAds = new NativeAd(context, requestConfig);
        nativeAds.setListener(new NativeAdsListener() {
            @Override
            public void onAdReady(List<NativeAdsResponse> responses) {
                if (responses == null || responses.size() == 0) {
                    CustomRecyclerAdLoader.this.onError(9999,"没有返回数据");
                    return;
                }
                 //如果是混合模式
                int adPatternType = getAdLoader().getAdPatternType();
                boolean isPreRender=false;
                if (adPatternType== MsAdPatternType.MIX_RENDER){
                    int drawing = getSdkAdInfo().getDrawing();
                    if (drawing == 1){
                        //自渲染
                        isPreRender = false;
                    }else if (drawing == 2){
                        isPreRender=true;
                    }else {
//                new CSJPlatformError("信息流模式不支持", -1, CSJTTAdNativeWrapper.this.getSdkAdInfo()).post(CSJTTAdNativeWrapper.this.loadListener);
                        return;
                    }
                }else if (adPatternType == MsAdPatternType.PRE_RENDER){
                    isPreRender = true;
                }
                if (responses != null) {
                    List<RecyclerAdData> adDatas = new ArrayList<>();
                    for (NativeAdsResponse response : responses) {
                        CustomFeedAd customFeedAd = new CustomFeedAd(CustomRecyclerAdLoader.this,response);
                        adDatas.add(customFeedAd);

                    }

                    CustomRecyclerAdLoader.this.onFeedAdLoad(adDatas);
                }
                if (isPreRender) {
                    loadExpressAd(responses);
                } else {
                    loadFeedAd(responses);
                }

            }

            @Override
            public void onAdFailed(String msg) {
                Log.e("CLOOOUDAD", "NativeAd onAdFailed: $s");
                CustomRecyclerAdLoader.this.onError(9999,msg);
            }
        });

    }

    private void loadFeedAd(List<NativeAdsResponse> responses) {
        if (responses != null) {
            List<RecyclerAdData> adDatas = new ArrayList<>();
            for (NativeAdsResponse response : responses) {
                CustomFeedAd customFeedAd = new CustomFeedAd(CustomRecyclerAdLoader.this,response);
                adDatas.add(customFeedAd);
            }

            CustomRecyclerAdLoader.this.onFeedAdLoad(adDatas);
        }
    }

    private void loadExpressAd(List<NativeAdsResponse> responses) {

        if (responses != null ) {
            List<RecyclerAdData> recyclerAdDatas = new ArrayList<>();
            for (NativeAdsResponse nativeAdsResponse : responses) {
                CustomExpressAd adData = new CustomExpressAd(CustomRecyclerAdLoader.this, nativeAdsResponse);
                nativeAdsResponse.setNativeActionListener(new NativeAdsResponse.NativeActionListener() {
                    @Override
                    public void onAdClick() {
                        CustomRecyclerAdLoader.this.onExpressAdClicked(adData);
                    }

                    @Override
                    public void onAdShow(CAdInfo cAdInfo) {
                        CustomRecyclerAdLoader.this.onExpressAdExposure(adData);
                    }

                    @Override
                    public void onError(String s) {
                        CustomRecyclerAdLoader.this.onRenderFail(9999,s);
                    }

                    @Override
                    public void onAdClose(String s) {
                        Log.e("CLOOOUD_POLY", "onAdClose: " );

                    }

                    @Override
                    public void onExpressRenderFail(String s) {
                        CustomRecyclerAdLoader.this.onRenderFail(9999,s);
                    }

                    @Override
                    public void onExpressRenderSuccess(View view, float v, float v1) {
                        CustomRecyclerAdLoader.this.onExpressAdRenderSuccess(adData);
                    }

                    @Override
                    public void onExpressRenderTimeout() {

                    }

                    @Override
                    public void onDislikeDialogShow() {

                    }

                    @Override
                    public void onDownloadConfirmDialogDismissed() {

                    }
                });

                nativeAdsResponse.render();
                recyclerAdDatas.add(adData);
            }

            CustomRecyclerAdLoader.this.onNativeExpressAdLoad(recyclerAdDatas);

        }
    }
}
