package com.yun.mshu;

import android.app.Activity;
import android.app.Application;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.View;
import android.widget.RelativeLayout;

import com.meishu.sdk.core.ad.AdSlot;
import com.meishu.sdk.core.ad.splash.SplashAdLoader;
import com.meishu.sdk.core.domain.SdkAdInfo;
import com.meishu.sdk.core.loader.AdPlatformError;
import com.meishu.sdk.core.utils.DimensionUtils;
import com.meishu.sdk.platform.custom.splash.MsCustomSplashAdapter;
import com.open.ad.cloooud.api.listener.COaidProvider;
import com.open.ad.polyunion.bean.CAdInfo;
import com.open.ad.polyunion.listener.AdViewListener;
import com.open.ad.polyunion.newedition.contract.DeniedUpDeviceInfo;
import com.open.ad.polyunion.newedition.contract.InitSDKListener;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.AdRequestConfig;
import com.open.ad.polyunion.view.AdView;
import com.open.ad.polyunion.view.InitSDKConfig;

/**
 * @author zw
 * @date :2025/2/8 10:46
 * @projectName
 * @description:
 */
public class CustomSplashAdLoader extends MsCustomSplashAdapter {
    private AdView splash;
    // 开屏广告视图父容器
    protected RelativeLayout mSplashRootContainer;

    public CustomSplashAdLoader(SplashAdLoader adLoader, SdkAdInfo sdkAdInfo) {
        super(adLoader, sdkAdInfo);
     }

    @Override
    public void loadCustomAd(String app_id, String s1, String pid, String s3) {
        try {
            //聚合SDK初始化
            InitSDKConfig initSDKConfig  = new InitSDKConfig.Builder()
                    .AppId(app_id)
//                    .setChannel("demo")//渠道
                    // 竖屏 - AdConfig.REWARD_VIDEO_SCREEN_VERTICAL
                    // 横屏 - AdConfig.REWARD_VIDEO_SCREEN_x`HORIZONTAL
                    .RewardVideoScreenDirection(AdConfig.REWARD_VIDEO_SCREEN_VERTICAL) // 设置激励视频播放页面的横竖屏
                    .debug(true)////上线需要设置false
                    .setDeniedUpDeviceInfo(new DeniedUpDeviceInfo() {
                    })
                    .setOaidProvider(new COaidProvider() {
                        @Override
                        public String getOaid() {
                            return "";
                        }
                    }) //传入 OAID 获取器，建议集成 OAID SDK的应用设置
                    .build();
            AdView.initSDK((Application) context.getApplicationContext(), initSDKConfig, new InitSDKListener() {
                @Override
                public void initializeSucceed() {
                    startLoadAd(pid);
                }

                @Override
                public void initializeFail() {
                    CustomSplashAdLoader.this.onError(10000,"初始化失败");
                    //初始化失败

                }
            });
        } catch (Throwable e) {
            CustomSplashAdLoader.this.onError(2000,e.getMessage());
        }
    }

    private void startLoadAd(String pid) {
        int adContentWidth = 1080;
        int adContentHeight = 1920;
        if (getAdLoader().getAccept_ad_width() !=null &&0 < getAdLoader().getAccept_ad_width() && getAdLoader().getAccept_ad_height()!=null && 0 < getAdLoader().getAccept_ad_height()) {
            adContentWidth  = getAdLoader().getAccept_ad_width();
            adContentHeight = getAdLoader().getAccept_ad_height();
        }else {
            try {
                DisplayMetrics displayMetrics = this.adLoader.getContext().getResources().getDisplayMetrics();
                if (0 < displayMetrics.widthPixels && 0 < displayMetrics.heightPixels) {
                    adContentWidth  = displayMetrics.widthPixels;
                    adContentHeight = displayMetrics.heightPixels;
                }
            } catch (Exception e) {}
        }
        if(!(context instanceof Activity)){
            return;
        }
        // 开屏广告则初始化视图容器
        mSplashRootContainer = new RelativeLayout(context.getApplicationContext());
         AdRequestConfig requestConfig = new AdRequestConfig.Builder()
                .AdType(AdConfig.AD_TYPE_SPLASH)
                .requestTimeOutMillis(5000) //设置聚合SDK请求前超时时间，毫秒
                .slotId(pid) //广告id
                .widthDp(adContentWidth) //请求图片宽度dp值
                .heightDp(adContentHeight) //需要传广告展示的高度
                .splashContainer(mSplashRootContainer) //设置开屏广告view容器
                .build();
        splash = new AdView((Activity) context, requestConfig);
        CustomSplashAd csjSplashAd = new CustomSplashAd(CustomSplashAdLoader.this,splash,mSplashRootContainer);

        splash.setListener(new AdViewListener() {
            @Override
            public void onAdClick() {
                Log.e("CLOOOUD_POLY", "onAdClick: " );
                CustomSplashAdLoader.this.onAdClick(csjSplashAd);
            }

            @Override
            public void onAdFailed(String msg) {
                CustomSplashAdLoader.this.onError(9999,msg);
                CustomSplashAdLoader.this.onAdTimeOver(csjSplashAd);

            }

            @Override
            public void onAdReady(int price) {
                CustomSplashAdLoader.this.setEcpm(price);
                CustomSplashAdLoader.this.onRenderSuccess(mSplashRootContainer,csjSplashAd);
            }

            @Override
            public void onAdShow(CAdInfo cAdInfo) {
                Log.e("CLOOOUD_POLY", "onAdShow: " );
                CustomSplashAdLoader.this.onAdExposure(csjSplashAd);
            }

            @Override
            public void onAdDismissed(String s) {
                Log.e("CLOOOUD_POLY", "onAdDismissed: " );
                CustomSplashAdLoader.this.onAdSkip(csjSplashAd);
            }
        });
    }

    @Override
    public void destroy() {
        super.destroy();
        splash.onDestroyAd();
    }
}
